#[repr(C)]pub struct MappingSessionOpenResponse {
pub size: u64,
}Fields
size: u64Trait Implementations
Sourceimpl Clone for MappingSessionOpenResponse
impl Clone for MappingSessionOpenResponse
Sourcefn clone(&self) -> MappingSessionOpenResponse
fn clone(&self) -> MappingSessionOpenResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MappingSessionOpenResponse
Sourceimpl Debug for MappingSessionOpenResponse
impl Debug for MappingSessionOpenResponse
Sourceimpl<D: ResourceDialect> Decode<MappingSessionOpenResponse, D> for MappingSessionOpenResponse
impl<D: ResourceDialect> Decode<MappingSessionOpenResponse, D> for MappingSessionOpenResponse
Sourceimpl<D: ResourceDialect> Encode<MappingSessionOpenResponse, D> for &MappingSessionOpenResponse
impl<D: ResourceDialect> Encode<MappingSessionOpenResponse, D> for &MappingSessionOpenResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u64, D>> Encode<MappingSessionOpenResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u64, D>> Encode<MappingSessionOpenResponse, D> for (T0,)
impl Eq for MappingSessionOpenResponse
Sourceimpl Hash for MappingSessionOpenResponse
impl Hash for MappingSessionOpenResponse
Sourceimpl Ord for MappingSessionOpenResponse
impl Ord for MappingSessionOpenResponse
Sourcefn cmp(&self, other: &MappingSessionOpenResponse) -> Ordering
fn cmp(&self, other: &MappingSessionOpenResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for MappingSessionOpenResponse
impl PartialOrd for MappingSessionOpenResponse
impl Persistable for MappingSessionOpenResponse
impl StructuralPartialEq for MappingSessionOpenResponse
Sourceimpl TypeMarker for MappingSessionOpenResponse
impl TypeMarker for MappingSessionOpenResponse
Sourcetype Owned = MappingSessionOpenResponse
type Owned = MappingSessionOpenResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for MappingSessionOpenResponse
impl ValueTypeMarker for MappingSessionOpenResponse
Sourcetype Borrowed<'a> = &'a MappingSessionOpenResponse
type Borrowed<'a> = &'a MappingSessionOpenResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for MappingSessionOpenResponse
impl RefUnwindSafe for MappingSessionOpenResponse
impl Send for MappingSessionOpenResponse
impl Sync for MappingSessionOpenResponse
impl Unpin for MappingSessionOpenResponse
impl UnsafeUnpin for MappingSessionOpenResponse
impl UnwindSafe for MappingSessionOpenResponse